pub enum MarineError {
InvalidConfig(String),
InstantiationError {
module_import_name: String,
modules_dir: Option<PathBuf>,
provided_modules: Vec<String>,
},
IOError(String),
MissingFunctionError(String),
MissingArgumentError(String),
NoSuchModule(String),
JsonArgumentsDeserializationError {
module_name: String,
function_name: String,
error: ITJsonSeDeError,
},
JsonOutputSerializationError {
module_name: String,
function_name: String,
error: ITJsonSeDeError,
},
ParseConfigError(Error),
EngineError(MError),
HighProbabilityOOM {
original_error: MError,
allocation_stats: MemoryAllocationStats,
},
}Variants
InvalidConfig(String)
Errors that happened due to invalid config content
InstantiationError
An error occurred at the instantiation step.
IOError(String)
Various errors related to file i/o.
MissingFunctionError(String)
A function with specified name is missing.
MissingArgumentError(String)
An argument with specified name is missing.
NoSuchModule(String)
Returns when there is no module with such name.
JsonArgumentsDeserializationError
Provided arguments aren’t compatible with a called function signature.
JsonOutputSerializationError
Returned outputs aren’t compatible with a called function signature.
ParseConfigError(Error)
Errors related to invalid config.
EngineError(MError)
Marine errors.
HighProbabilityOOM
When marine returned an error and there was a rejected allocation, the most probable cause is OOM. Otherwise this error is the same as EngineError. This error is on marine-runtime level, because otherwise it is impossible to check allocation stats after a failed instantiation.