Struct marine::MModuleConfig [−][src]
pub struct MModuleConfig {
pub mem_pages_count: u32,
pub raw_imports: ImportObject,
pub host_imports: HashMap<String, HostImportDescriptor>,
pub wasi_version: WasiVersion,
pub wasi_envs: HashMap<Vec<u8>, Vec<u8>>,
pub wasi_preopened_files: HashSet<PathBuf>,
pub wasi_mapped_dirs: HashMap<String, PathBuf>,
}Fields
mem_pages_count: u32Maximum number of Wasm memory pages that loaded module can use. Each Wasm pages is 65536 bytes long.
raw_imports: ImportObjectImport object that will be used in module instantiation process.
host_imports: HashMap<String, HostImportDescriptor>Imports from the host side that will be used in module instantiation process.
wasi_version: WasiVersionDesired WASI version.
wasi_envs: HashMap<Vec<u8>, Vec<u8>>Environment variables for loaded modules.
wasi_preopened_files: HashSet<PathBuf>List of available directories for loaded modules.
wasi_mapped_dirs: HashMap<String, PathBuf>Mapping between paths.
Implementations
impl MModuleConfig[src]
impl MModuleConfig[src]pub fn with_mem_pages_count(self, mem_pages_count: u32) -> Self[src]
pub fn with_wasi_version(self, wasi_version: WasiVersion) -> Self[src]
pub fn with_wasi_envs(self, envs: HashMap<Vec<u8>, Vec<u8>>) -> Self[src]
pub fn with_wasi_preopened_files(
self,
preopened_files: HashSet<PathBuf>
) -> Self[src]
self,
preopened_files: HashSet<PathBuf>
) -> Self
pub fn with_wasi_mapped_dirs(
self,
mapped_dirs: HashMap<String, PathBuf>
) -> Self[src]
self,
mapped_dirs: HashMap<String, PathBuf>
) -> Self